import { FC, ReactNode } from 'react';
import { IconNames } from '@/assets/iconfont';
import './index.less';
/** 图片tabbar属性 */
interface BitzTabbarItemImageConfig {
    /** 常规状态下的图片资源 */
    inactiveImage: string;
    /** 选中状态下的图片资源 */
    activeImage: string;
    /** 常规状态下的title文字颜色 */
    inactiveColor?: string | string[];
    /** 选中状态下的title文字颜色 */
    activeColor?: string | string[];
}
/** icon tabbar属性 */
interface BitzTabbarItemIconConfig {
    /** 常规状态下的icon */
    inactiveIcon: IconNames;
    /** 选中状态下的icon */
    activeIcon: IconNames;
    /** 常规状态下的title文字和icon颜色 */
    inactiveColor?: string | string[];
    /** 选中状态下的title文字和icon颜色 */
    activeColor?: string | string[];
}
/** 数字角标增强属性，新增zeroHidden，控制角标数字为0时是否显示角标 */
interface BitzTabbarItemBadgeConfig {
    /** 角标数字 */
    num: number;
    color: string;
    /** num为0时是否显示角标 */
    zeroHidden?: boolean;
}
/**  TabbarItem属性 */
export interface BitzTabbarItemProps {
    /** 当前TabbarItem的唯一标识符（索引值或名称） */
    currentName?: string | number;
    /** TabbarItem的唯一标识符（索引值或名称） */
    name: string | number;
    /** 图标/图片配置（选中和常规（未选中）状态的图标/图片/文字的样式） */
    config: BitzTabbarItemImageConfig | BitzTabbarItemIconConfig;
    /** TabbarItem的title */
    title?: string;
    /** TabbarItem的title，需要使用闭合标签（ReactNode版本） */
    children?: ReactNode;
    /** 红点角标 */
    dot?: boolean;
    /** 带数字的角标 */
    badge?: number | BitzTabbarItemBadgeConfig;
    /** Tabbar在route模式下，路由跳转参数 */
    to?: string | object;
    /** Tabbar在route模式下，路由跳转时是否关闭当前页面，并打开新页面 */
    replace?: boolean;
}
/** TabbarItem Componet */
declare const BitzTabbarItem: FC<BitzTabbarItemProps>;
export default BitzTabbarItem;
